@@ -7,5 +7,8 @@ match most of the traffic, so the other rules only apply to not yet established
 connections.
 """
 iptables("INPUT",  "-m state --state ESTABLISHED,RELATED -j %s" % Firewall.accept)
+iptables("INPUT",  "-m state --state INVALID -j %s" % Firewall.drop)
 iptables("OUTPUT", "-m state --state ESTABLISHED,RELATED -j %s" % Firewall.accept)
+iptables("OUTPUT",  "-m state --state INVALID -j %s" % Firewall.drop)
 iptables("FORWARD","-m state --state ESTABLISHED,RELATED -j %s" % Firewall.accept)
+iptables("FORWARD",  "-m state --state INVALID -j %s" % Firewall.drop)
